Class: Google::Apis::DomainsV1::CustomDns

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

Configuration for an arbitrary DNS provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomDns

Returns a new instance of CustomDns.



442
443
444
# File 'lib/google/apis/domains_v1/classes.rb', line 442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ds_recordsArray<Google::Apis::DomainsV1::DsRecord>

The list of DS records for this domain, which are used to enable DNSSEC. The domain's DNS provider can provide the values to set here. If this field is empty, DNSSEC is disabled. Corresponds to the JSON property dsRecords



433
434
435
# File 'lib/google/apis/domains_v1/classes.rb', line 433

def ds_records
  @ds_records
end

#name_serversArray<String>

Required. A list of name servers that store the DNS zone for this domain. Each name server is a domain name, with Unicode domain names expressed in Punycode format. Corresponds to the JSON property nameServers

Returns:

  • (Array<String>)


440
441
442
# File 'lib/google/apis/domains_v1/classes.rb', line 440

def name_servers
  @name_servers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



447
448
449
450
# File 'lib/google/apis/domains_v1/classes.rb', line 447

def update!(**args)
  @ds_records = args[:ds_records] if args.key?(:ds_records)
  @name_servers = args[:name_servers] if args.key?(:name_servers)
end