Class: Google::Apis::DomainsV1::EmailForwarding
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1::EmailForwarding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb
Overview
Email forwarding configuration.
Instance Attribute Summary collapse
-
#alias ⇒ String
An alias recipient email that forwards emails to the
target_email_address. -
#target_email_address ⇒ String
Target email that receives emails sent to the
alias.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmailForwarding
constructor
A new instance of EmailForwarding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmailForwarding
Returns a new instance of EmailForwarding.
637 638 639 |
# File 'lib/google/apis/domains_v1/classes.rb', line 637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alias ⇒ String
An alias recipient email that forwards emails to the target_email_address.
For example, admin@example.com or *@example.com (wildcard alias forwards
all the emails under the registered domain).
Corresponds to the JSON property alias
630 631 632 |
# File 'lib/google/apis/domains_v1/classes.rb', line 630 def alias @alias end |
#target_email_address ⇒ String
Target email that receives emails sent to the alias.
Corresponds to the JSON property targetEmailAddress
635 636 637 |
# File 'lib/google/apis/domains_v1/classes.rb', line 635 def target_email_address @target_email_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
642 643 644 645 |
# File 'lib/google/apis/domains_v1/classes.rb', line 642 def update!(**args) @alias = args[:alias] if args.key?(:alias) @target_email_address = args[:target_email_address] if args.key?(:target_email_address) end |