Class: Google::Apis::DomainsV1::HealthCheckTargets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckTargets

Returns a new instance of HealthCheckTargets.



894
895
896
# File 'lib/google/apis/domains_v1/classes.rb', line 894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_endpointsArray<String>

The Internet IP addresses to be health checked. The format matches the format of ResourceRecordSet.rrdata as defined in RFC 1035 (section 5) and RFC 1034 ( section 3.6.1) Corresponds to the JSON property externalEndpoints

Returns:

  • (Array<String>)


887
888
889
# File 'lib/google/apis/domains_v1/classes.rb', line 887

def external_endpoints
  @external_endpoints
end

#internal_load_balancerArray<Google::Apis::DomainsV1::LoadBalancerTarget>

Configuration for internal load balancers to be health checked. Corresponds to the JSON property internalLoadBalancer



892
893
894
# File 'lib/google/apis/domains_v1/classes.rb', line 892

def internal_load_balancer
  @internal_load_balancer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



899
900
901
902
# File 'lib/google/apis/domains_v1/classes.rb', line 899

def update!(**args)
  @external_endpoints = args[:external_endpoints] if args.key?(:external_endpoints)
  @internal_load_balancer = args[:internal_load_balancer] if args.key?(:internal_load_balancer)
end