Class: Google::Apis::DomainsV1::ManagementSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

Defines renewal, billing, and transfer settings for a Registration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagementSettings

Returns a new instance of ManagementSettings.



1203
1204
1205
# File 'lib/google/apis/domains_v1/classes.rb', line 1203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_transfer_lock_stateString

Output only. The actual transfer lock state for this Registration. Corresponds to the JSON property effectiveTransferLockState

Returns:

  • (String)


1162
1163
1164
# File 'lib/google/apis/domains_v1/classes.rb', line 1162

def effective_transfer_lock_state
  @effective_transfer_lock_state
end

#preferred_renewal_methodString

Optional. The desired renewal method for this Registration. The actual renewal_method is automatically updated to reflect this choice. If unset or equal to RENEWAL_METHOD_UNSPECIFIED, the actual renewalMethod is treated as if it were set to AUTOMATIC_RENEWAL. You cannot use RENEWAL_DISABLED during resource creation, and you can update the renewal status only when the Registration resource has state ACTIVE or SUSPENDED. When preferred_renewal_method is set to AUTOMATIC_RENEWAL, the actual renewal_method can be set to RENEWAL_DISABLED in case of problems with the billing account or reported domain abuse. In such cases, check the issues field on the Registration. After the problem is resolved, the renewal_method is automatically updated to preferred_renewal_method in a few hours. Corresponds to the JSON property preferredRenewalMethod

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/domains_v1/classes.rb', line 1178

def preferred_renewal_method
  @preferred_renewal_method
end

#renewal_methodString

Output only. The actual renewal method for this Registration. When preferred_renewal_method is set to AUTOMATIC_RENEWAL, the actual renewal_method can be equal to RENEWAL_DISABLED—for example, when there are problems with the billing account or reported domain abuse. In such cases, check the issues field on the Registration. After the problem is resolved, the renewal_method is automatically updated to preferred_renewal_method in a few hours. Corresponds to the JSON property renewalMethod

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/domains_v1/classes.rb', line 1189

def renewal_method
  @renewal_method
end

#transfer_lock_stateString

This is the desired transfer lock state for this Registration. A transfer lock controls whether the domain can be transferred to another registrar. The transfer lock state of the domain is returned in the effective_transfer_lock_state property. The transfer lock state values might be different for the following reasons: * transfer_lock_state was updated only a short time ago. * Domains with the TRANSFER_LOCK_UNSUPPORTED_BY_REGISTRY state are in the list of domain_properties. These domains are always in the UNLOCKED state. Corresponds to the JSON property transferLockState

Returns:

  • (String)


1201
1202
1203
# File 'lib/google/apis/domains_v1/classes.rb', line 1201

def transfer_lock_state
  @transfer_lock_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1208
1209
1210
1211
1212
1213
# File 'lib/google/apis/domains_v1/classes.rb', line 1208

def update!(**args)
  @effective_transfer_lock_state = args[:effective_transfer_lock_state] if args.key?(:effective_transfer_lock_state)
  @preferred_renewal_method = args[:preferred_renewal_method] if args.key?(:preferred_renewal_method)
  @renewal_method = args[:renewal_method] if args.key?(:renewal_method)
  @transfer_lock_state = args[:transfer_lock_state] if args.key?(:transfer_lock_state)
end