Class: Google::Apis::DomainsV1::PrimaryBackupPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy. And if all of them are unhealthy, then we fallback to a geo localized policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrimaryBackupPolicy

Returns a new instance of PrimaryBackupPolicy.



1611
1612
1613
# File 'lib/google/apis/domains_v1/classes.rb', line 1611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_geo_targetsGoogle::Apis::DomainsV1::GeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property backupGeoTargets



1595
1596
1597
# File 'lib/google/apis/domains_v1/classes.rb', line 1595

def backup_geo_targets
  @backup_geo_targets
end

#primary_targetsGoogle::Apis::DomainsV1::HealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property primaryTargets



1603
1604
1605
# File 'lib/google/apis/domains_v1/classes.rb', line 1603

def primary_targets
  @primary_targets
end

#trickle_trafficFloat

When serving state is PRIMARY, this field provides the option of sending a small percentage of the traffic to the backup targets. Corresponds to the JSON property trickleTraffic

Returns:

  • (Float)


1609
1610
1611
# File 'lib/google/apis/domains_v1/classes.rb', line 1609

def trickle_traffic
  @trickle_traffic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1616
1617
1618
1619
1620
# File 'lib/google/apis/domains_v1/classes.rb', line 1616

def update!(**args)
  @backup_geo_targets = args[:backup_geo_targets] if args.key?(:backup_geo_targets)
  @primary_targets = args[:primary_targets] if args.key?(:primary_targets)
  @trickle_traffic = args[:trickle_traffic] if args.key?(:trickle_traffic)
end