Class: Google::Apis::DomainsV1::RenewDomainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

Request for the RenewDomain method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RenewDomainRequest

Returns a new instance of RenewDomainRequest.



1946
1947
1948
# File 'lib/google/apis/domains_v1/classes.rb', line 1946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#validate_onlyBoolean Also known as: validate_only?

Optional. When true, only validation is performed, without actually renewing the domain. For more information, see Request validation Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1938
1939
1940
# File 'lib/google/apis/domains_v1/classes.rb', line 1938

def validate_only
  @validate_only
end

#yearly_priceGoogle::Apis::DomainsV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property yearlyPrice



1944
1945
1946
# File 'lib/google/apis/domains_v1/classes.rb', line 1944

def yearly_price
  @yearly_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1951
1952
1953
1954
# File 'lib/google/apis/domains_v1/classes.rb', line 1951

def update!(**args)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
  @yearly_price = args[:yearly_price] if args.key?(:yearly_price)
end