Class: Google::Apis::DomainsV1::TransferDomainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

Deprecated: For more information, see Cloud Domains feature deprecation. Request for the TransferDomain method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferDomainRequest

Returns a new instance of TransferDomainRequest.



2351
2352
2353
# File 'lib/google/apis/domains_v1/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorization_codeGoogle::Apis::DomainsV1::AuthorizationCode

Defines an authorization code. Corresponds to the JSON property authorizationCode



2308
2309
2310
# File 'lib/google/apis/domains_v1/classes.rb', line 2308

def authorization_code
  @authorization_code
end

#contact_noticesArray<String>

The list of contact notices that you acknowledge. The notices needed here depend on the values specified in registration.contact_settings. Corresponds to the JSON property contactNotices

Returns:

  • (Array<String>)


2314
2315
2316
# File 'lib/google/apis/domains_v1/classes.rb', line 2314

def contact_notices
  @contact_notices
end

#registrationGoogle::Apis::DomainsV1::Registration

The Registration resource facilitates managing and configuring domain name registrations. There are several ways to create a new Registration resource: To create a new Registration resource, find a suitable domain name by calling the SearchDomains method with a query to see available domain name options. After choosing a name, call RetrieveRegisterParameters to ensure availability and obtain information like pricing, which is needed to build a call to RegisterDomain. Another way to create a new Registration is to transfer an existing domain from another registrar (Deprecated: For more information, see Cloud Domains feature deprecation). First, go to the current registrar to unlock the domain for transfer and retrieve the domain's transfer authorization code. Then call RetrieveTransferParameters to confirm that the domain is unlocked and to get values needed to build a call to TransferDomain . Finally, you can create a new Registration by importing an existing domain managed with Google Domains (Deprecated: For more information, see Cloud Domains feature deprecation). First, call RetrieveImportableDomains to list domains to which the calling user has sufficient access. Then call ImportDomain on any domain names you want to use with Cloud Domains. Corresponds to the JSON property registration



2338
2339
2340
# File 'lib/google/apis/domains_v1/classes.rb', line 2338

def registration
  @registration
end

#validate_onlyBoolean Also known as: validate_only?

Validate the request without actually transferring the domain. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2343
2344
2345
# File 'lib/google/apis/domains_v1/classes.rb', line 2343

def validate_only
  @validate_only
end

#yearly_priceGoogle::Apis::DomainsV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property yearlyPrice



2349
2350
2351
# File 'lib/google/apis/domains_v1/classes.rb', line 2349

def yearly_price
  @yearly_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
2360
2361
2362
# File 'lib/google/apis/domains_v1/classes.rb', line 2356

def update!(**args)
  @authorization_code = args[:authorization_code] if args.key?(:authorization_code)
  @contact_notices = args[:contact_notices] if args.key?(:contact_notices)
  @registration = args[:registration] if args.key?(:registration)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
  @yearly_price = args[:yearly_price] if args.key?(:yearly_price)
end