Class: Google::Apis::DomainsV1::WrrPolicyItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

A routing block which contains the routing information for one WRR item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WrrPolicyItem

Returns a new instance of WrrPolicyItem.



2483
2484
2485
# File 'lib/google/apis/domains_v1/classes.rb', line 2483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_checked_targetsGoogle::Apis::DomainsV1::HealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property healthCheckedTargets



2461
2462
2463
# File 'lib/google/apis/domains_v1/classes.rb', line 2461

def health_checked_targets
  @health_checked_targets
end

#rrdataArray<String>

Corresponds to the JSON property rrdata

Returns:

  • (Array<String>)


2466
2467
2468
# File 'lib/google/apis/domains_v1/classes.rb', line 2466

def rrdata
  @rrdata
end

#signature_rrdataArray<String>

DNSSEC generated signatures for all the rrdata within this item. When using health-checked targets for DNSSEC-enabled zones, you can only use at most one health-checked IP address per item. Corresponds to the JSON property signatureRrdata

Returns:

  • (Array<String>)


2473
2474
2475
# File 'lib/google/apis/domains_v1/classes.rb', line 2473

def signature_rrdata
  @signature_rrdata
end

#weightFloat

The weight corresponding to this WrrPolicyItem object. When multiple WrrPolicyItem objects are configured, the probability of returning an WrrPolicyItem object's data is proportional to its weight relative to the sum of weights configured for all items. This weight must be non-negative. Corresponds to the JSON property weight

Returns:

  • (Float)


2481
2482
2483
# File 'lib/google/apis/domains_v1/classes.rb', line 2481

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2488
2489
2490
2491
2492
2493
# File 'lib/google/apis/domains_v1/classes.rb', line 2488

def update!(**args)
  @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets)
  @rrdata = args[:rrdata] if args.key?(:rrdata)
  @signature_rrdata = args[:signature_rrdata] if args.key?(:signature_rrdata)
  @weight = args[:weight] if args.key?(:weight)
end