Class: Google::Apis::DomainsV1::Contact
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1::Contact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb
Overview
Details required for a contact associated with a Registration.
Instance Attribute Summary collapse
-
#email ⇒ String
Required.
-
#fax_number ⇒ String
Fax number of the contact in international format.
-
#phone_number ⇒ String
Required.
-
#postal_address ⇒ Google::Apis::DomainsV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Contact
constructor
A new instance of Contact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Contact
Returns a new instance of Contact.
363 364 365 |
# File 'lib/google/apis/domains_v1/classes.rb', line 363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Required. Email address of the contact.
Corresponds to the JSON property email
334 335 336 |
# File 'lib/google/apis/domains_v1/classes.rb', line 334 def email @email end |
#fax_number ⇒ String
Fax number of the contact in international format. For example, "+1-800-555-
0123".
Corresponds to the JSON property faxNumber
340 341 342 |
# File 'lib/google/apis/domains_v1/classes.rb', line 340 def fax_number @fax_number end |
#phone_number ⇒ String
Required. Phone number of the contact in international format. For example, "+
1-800-555-0123".
Corresponds to the JSON property phoneNumber
346 347 348 |
# File 'lib/google/apis/domains_v1/classes.rb', line 346 def phone_number @phone_number end |
#postal_address ⇒ Google::Apis::DomainsV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property postalAddress
361 362 363 |
# File 'lib/google/apis/domains_v1/classes.rb', line 361 def postal_address @postal_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
368 369 370 371 372 373 |
# File 'lib/google/apis/domains_v1/classes.rb', line 368 def update!(**args) @email = args[:email] if args.key?(:email) @fax_number = args[:fax_number] if args.key?(:fax_number) @phone_number = args[:phone_number] if args.key?(:phone_number) @postal_address = args[:postal_address] if args.key?(:postal_address) end |