Class: Google::Apis::DomainsV1::LoadBalancerTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

The configuration for an individual load balancer to health check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerTarget

Returns a new instance of LoadBalancerTarget.



1092
1093
1094
# File 'lib/google/apis/domains_v1/classes.rb', line 1092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The frontend IP address of the load balancer to health check. Corresponds to the JSON property ipAddress

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/domains_v1/classes.rb', line 1053

def ip_address
  @ip_address
end

#ip_protocolString

The protocol of the load balancer to health check. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


1058
1059
1060
# File 'lib/google/apis/domains_v1/classes.rb', line 1058

def ip_protocol
  @ip_protocol
end

#load_balancer_typeString

The type of load balancer specified by this target. This value must match the configuration of the load balancer located at the LoadBalancerTarget's IP address, port, and region. Use the following: - regionalL4ilb: for a regional internal passthrough Network Load Balancer. - regionalL7ilb: for a regional internal Application Load Balancer. - globalL7ilb: for a global internal Application Load Balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


1068
1069
1070
# File 'lib/google/apis/domains_v1/classes.rb', line 1068

def load_balancer_type
  @load_balancer_type
end

#network_urlString

The fully qualified URL of the network that the load balancer is attached to. This should be formatted like https://www.googleapis.com/compute/v1/projects/ project/global/networks/network`. Corresponds to the JSON propertynetworkUrl`

Returns:

  • (String)


1075
1076
1077
# File 'lib/google/apis/domains_v1/classes.rb', line 1075

def network_url
  @network_url
end

#portString

The configured port of the load balancer. Corresponds to the JSON property port

Returns:

  • (String)


1080
1081
1082
# File 'lib/google/apis/domains_v1/classes.rb', line 1080

def port
  @port
end

#projectString

The project ID in which the load balancer is located. Corresponds to the JSON property project

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/domains_v1/classes.rb', line 1085

def project
  @project
end

#regionString

The region in which the load balancer is located. Corresponds to the JSON property region

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/domains_v1/classes.rb', line 1090

def region
  @region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/google/apis/domains_v1/classes.rb', line 1097

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
  @network_url = args[:network_url] if args.key?(:network_url)
  @port = args[:port] if args.key?(:port)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
end