Class: Google::Apis::DomainsV1::Registration
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1::Registration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb
Overview
The Registration resource facilitates managing and configuring domain name
registrations. There are several ways to create a new Registration resource:
To create a new Registration resource, find a suitable domain name by
calling the SearchDomains method with a query to see available domain name
options. After choosing a name, call RetrieveRegisterParameters to ensure
availability and obtain information like pricing, which is needed to build a
call to RegisterDomain. Another way to create a new Registration is to
transfer an existing domain from another registrar (Deprecated: For more
information, see Cloud Domains feature deprecation). First, go to the current
registrar to unlock the domain for transfer and retrieve the domain's transfer
authorization code. Then call RetrieveTransferParameters to confirm that the
domain is unlocked and to get values needed to build a call to TransferDomain
. Finally, you can create a new Registration by importing an existing domain
managed with Google Domains (Deprecated: For more
information, see Cloud Domains feature deprecation). First, call
RetrieveImportableDomains to list domains to which the calling user has
sufficient access. Then call ImportDomain on any domain names you want to
use with Cloud Domains.
Instance Attribute Summary collapse
-
#contact_settings ⇒ Google::Apis::DomainsV1::ContactSettings
Defines the contact information associated with a
Registration. -
#create_time ⇒ String
Output only.
-
#dns_settings ⇒ Google::Apis::DomainsV1::DnsSettings
Defines the DNS configuration of a
Registration, including name servers, DNSSEC, and glue records. -
#domain_name ⇒ String
Required.
-
#domain_properties ⇒ Array<String>
Output only.
-
#expire_time ⇒ String
Output only.
-
#issues ⇒ Array<String>
Output only.
-
#labels ⇒ Hash<String,String>
Set of labels associated with the
Registration. -
#management_settings ⇒ Google::Apis::DomainsV1::ManagementSettings
Defines renewal, billing, and transfer settings for a
Registration. -
#name ⇒ String
Output only.
-
#pending_contact_settings ⇒ Google::Apis::DomainsV1::ContactSettings
Defines the contact information associated with a
Registration. -
#register_failure_reason ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supported_privacy ⇒ Array<String>
Output only.
-
#transfer_failure_reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Registration
constructor
A new instance of Registration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Registration
Returns a new instance of Registration.
1913 1914 1915 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contact_settings ⇒ Google::Apis::DomainsV1::ContactSettings
Defines the contact information associated with a Registration. ICANN requires all domain names to have associated contact
information. The registrant_contact is considered the domain's legal owner,
and often the other contacts are identical.
Corresponds to the JSON property contactSettings
1830 1831 1832 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1830 def contact_settings @contact_settings end |
#create_time ⇒ String
Output only. The creation timestamp of the Registration resource.
Corresponds to the JSON property createTime
1835 1836 1837 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1835 def create_time @create_time end |
#dns_settings ⇒ Google::Apis::DomainsV1::DnsSettings
Defines the DNS configuration of a Registration, including name servers,
DNSSEC, and glue records.
Corresponds to the JSON property dnsSettings
1841 1842 1843 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1841 def dns_settings @dns_settings end |
#domain_name ⇒ String
Required. Immutable. The domain name. Unicode domain names must be expressed
in Punycode format.
Corresponds to the JSON property domainName
1847 1848 1849 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1847 def domain_name @domain_name end |
#domain_properties ⇒ Array<String>
Output only. Special properties of the domain.
Corresponds to the JSON property domainProperties
1852 1853 1854 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1852 def domain_properties @domain_properties end |
#expire_time ⇒ String
Output only. The expiration timestamp of the Registration.
Corresponds to the JSON property expireTime
1857 1858 1859 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1857 def expire_time @expire_time end |
#issues ⇒ Array<String>
Output only. The set of issues with the Registration that require attention.
Corresponds to the JSON property issues
1862 1863 1864 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1862 def issues @issues end |
#labels ⇒ Hash<String,String>
Set of labels associated with the Registration.
Corresponds to the JSON property labels
1867 1868 1869 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1867 def labels @labels end |
#management_settings ⇒ Google::Apis::DomainsV1::ManagementSettings
Defines renewal, billing, and transfer settings for a Registration.
Corresponds to the JSON property managementSettings
1872 1873 1874 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1872 def management_settings @management_settings end |
#name ⇒ String
Output only. Name of the Registration resource, in the format projects/*/
locations/*/registrations/.
Corresponds to the JSON property name
1878 1879 1880 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1878 def name @name end |
#pending_contact_settings ⇒ Google::Apis::DomainsV1::ContactSettings
Defines the contact information associated with a Registration. ICANN requires all domain names to have associated contact
information. The registrant_contact is considered the domain's legal owner,
and often the other contacts are identical.
Corresponds to the JSON property pendingContactSettings
1886 1887 1888 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1886 def pending_contact_settings @pending_contact_settings end |
#register_failure_reason ⇒ String
Output only. The reason the domain registration failed. Only set for domains
in REGISTRATION_FAILED state.
Corresponds to the JSON property registerFailureReason
1892 1893 1894 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1892 def register_failure_reason @register_failure_reason end |
#state ⇒ String
Output only. The state of the Registration
Corresponds to the JSON property state
1897 1898 1899 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1897 def state @state end |
#supported_privacy ⇒ Array<String>
Output only. Set of options for the contact_settings.privacy field that this
Registration supports.
Corresponds to the JSON property supportedPrivacy
1903 1904 1905 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1903 def supported_privacy @supported_privacy end |
#transfer_failure_reason ⇒ String
Output only. Deprecated: For more information, see Cloud Domains feature
deprecation. The reason the domain transfer failed. Only set for domains in
TRANSFER_FAILED state.
Corresponds to the JSON property transferFailureReason
1911 1912 1913 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1911 def transfer_failure_reason @transfer_failure_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1918 def update!(**args) @contact_settings = args[:contact_settings] if args.key?(:contact_settings) @create_time = args[:create_time] if args.key?(:create_time) @dns_settings = args[:dns_settings] if args.key?(:dns_settings) @domain_name = args[:domain_name] if args.key?(:domain_name) @domain_properties = args[:domain_properties] if args.key?(:domain_properties) @expire_time = args[:expire_time] if args.key?(:expire_time) @issues = args[:issues] if args.key?(:issues) @labels = args[:labels] if args.key?(:labels) @management_settings = args[:management_settings] if args.key?(:management_settings) @name = args[:name] if args.key?(:name) @pending_contact_settings = args[:pending_contact_settings] if args.key?(:pending_contact_settings) @register_failure_reason = args[:register_failure_reason] if args.key?(:register_failure_reason) @state = args[:state] if args.key?(:state) @supported_privacy = args[:supported_privacy] if args.key?(:supported_privacy) @transfer_failure_reason = args[:transfer_failure_reason] if args.key?(:transfer_failure_reason) end |