Class: Google::Apis::DomainsV1::RrSetRoutingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1::RrSetRoutingPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb
Overview
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
Instance Attribute Summary collapse
-
#geo ⇒ Google::Apis::DomainsV1::GeoPolicy
Configures a
RRSetRoutingPolicythat routes based on the geo location of the querying user. -
#geo_policy ⇒ Google::Apis::DomainsV1::GeoPolicy
Configures a
RRSetRoutingPolicythat routes based on the geo location of the querying user. -
#health_check ⇒ String
The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy.
-
#primary_backup ⇒ Google::Apis::DomainsV1::PrimaryBackupPolicy
Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy.
-
#wrr ⇒ Google::Apis::DomainsV1::WrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
-
#wrr_policy ⇒ Google::Apis::DomainsV1::WrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicy
constructor
A new instance of RrSetRoutingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicy
Returns a new instance of RrSetRoutingPolicy.
1674 1675 1676 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo ⇒ Google::Apis::DomainsV1::GeoPolicy
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Corresponds to the JSON property geo
1641 1642 1643 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1641 def geo @geo end |
#geo_policy ⇒ Google::Apis::DomainsV1::GeoPolicy
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Corresponds to the JSON property geoPolicy
1647 1648 1649 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1647 def geo_policy @geo_policy end |
#health_check ⇒ String
The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy.
Format this URL like https://www.googleapis.com/compute/v1/projects/project/
global/healthChecks/healthCheck`. https://cloud.google.com/compute/docs/
reference/rest/v1/healthChecks
Corresponds to the JSON propertyhealthCheck`
1655 1656 1657 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1655 def health_check @health_check end |
#primary_backup ⇒ Google::Apis::DomainsV1::PrimaryBackupPolicy
Configures a RRSetRoutingPolicy such that all queries are responded with the
primary_targets if they are healthy. And if all of them are unhealthy, then we
fallback to a geo localized policy.
Corresponds to the JSON property primaryBackup
1662 1663 1664 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1662 def primary_backup @primary_backup end |
#wrr ⇒ Google::Apis::DomainsV1::WrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
Corresponds to the JSON property wrr
1667 1668 1669 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1667 def wrr @wrr end |
#wrr_policy ⇒ Google::Apis::DomainsV1::WrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
Corresponds to the JSON property wrrPolicy
1672 1673 1674 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1672 def wrr_policy @wrr_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/google/apis/domains_v1/classes.rb', line 1679 def update!(**args) @geo = args[:geo] if args.key?(:geo) @geo_policy = args[:geo_policy] if args.key?(:geo_policy) @health_check = args[:health_check] if args.key?(:health_check) @primary_backup = args[:primary_backup] if args.key?(:primary_backup) @wrr = args[:wrr] if args.key?(:wrr) @wrr_policy = args[:wrr_policy] if args.key?(:wrr_policy) end |