Class: Google::Apis::DomainsV1::RrSetRoutingPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1/classes.rb,
lib/google/apis/domains_v1/representations.rb,
lib/google/apis/domains_v1/representations.rb

Overview

A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicy

Returns a new instance of RrSetRoutingPolicy.



1666
1667
1668
# File 'lib/google/apis/domains_v1/classes.rb', line 1666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geoGoogle::Apis::DomainsV1::GeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property geo



1633
1634
1635
# File 'lib/google/apis/domains_v1/classes.rb', line 1633

def geo
  @geo
end

#geo_policyGoogle::Apis::DomainsV1::GeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property geoPolicy



1639
1640
1641
# File 'lib/google/apis/domains_v1/classes.rb', line 1639

def geo_policy
  @geo_policy
end

#health_checkString

The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy. Format this URL like https://www.googleapis.com/compute/v1/projects/project/ global/healthChecks/healthCheck`. https://cloud.google.com/compute/docs/ reference/rest/v1/healthChecks Corresponds to the JSON propertyhealthCheck`

Returns:

  • (String)


1647
1648
1649
# File 'lib/google/apis/domains_v1/classes.rb', line 1647

def health_check
  @health_check
end

#primary_backupGoogle::Apis::DomainsV1::PrimaryBackupPolicy

Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy. And if all of them are unhealthy, then we fallback to a geo localized policy. Corresponds to the JSON property primaryBackup



1654
1655
1656
# File 'lib/google/apis/domains_v1/classes.rb', line 1654

def primary_backup
  @primary_backup
end

#wrrGoogle::Apis::DomainsV1::WrrPolicy

Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion. Corresponds to the JSON property wrr



1659
1660
1661
# File 'lib/google/apis/domains_v1/classes.rb', line 1659

def wrr
  @wrr
end

#wrr_policyGoogle::Apis::DomainsV1::WrrPolicy

Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion. Corresponds to the JSON property wrrPolicy



1664
1665
1666
# File 'lib/google/apis/domains_v1/classes.rb', line 1664

def wrr_policy
  @wrr_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1671
1672
1673
1674
1675
1676
1677
1678
# File 'lib/google/apis/domains_v1/classes.rb', line 1671

def update!(**args)
  @geo = args[:geo] if args.key?(:geo)
  @geo_policy = args[:geo_policy] if args.key?(:geo_policy)
  @health_check = args[:health_check] if args.key?(:health_check)
  @primary_backup = args[:primary_backup] if args.key?(:primary_backup)
  @wrr = args[:wrr] if args.key?(:wrr)
  @wrr_policy = args[:wrr_policy] if args.key?(:wrr_policy)
end